"""
Model management for viby - handles interactions with LLM providers
"""

import openai
from typing import Iterator, Dict, Any
from viby.config import Config
from viby.locale import get_text


class ModelManager:
    
    def __init__(self, config: Config):
        self.config = config
        
    
    def stream_response(self, prompt: str) -> Iterator[str]:
        """流式获取模型回复"""
        model_config = self.config.get_model_config()
        yield from self._call_llm(prompt, model_config)
    
    def _call_llm(self, prompt: str, model_config: Dict[str, Any]) -> Iterator[str]:
        model = model_config["model"]
        base_url = model_config["base_url"].rstrip("/")
        api_key = model_config.get("api_key", "")
        
        try:
            client = openai.OpenAI(
                api_key=api_key or "EMPTY",
                base_url=f"{base_url}/v1"
            )
            
            # 准备请求参数
            params = {
                "model": model,
                "messages": [{"role": "user", "content": prompt}],
                "temperature": model_config["temperature"],
                "max_tokens": model_config["max_tokens"],
                "stream": True,
            }
            
            stream = client.chat.completions.create(**params)
            
            # 检查是否有响应内容
            has_content = False
            
            for chunk in stream:
                if chunk.choices and chunk.choices[0].delta.content:
                    has_content = True
                    yield chunk.choices[0].delta.content
            
            # 如果整个流中没有内容，则提示用户
            if not has_content:
                yield get_text("GENERAL", "llm_empty_response")
                
        except Exception as e:
            yield f"Error: {str(e)}"



import re
from rich.console import Console
from rich.markdown import Markdown

class Colors:
    # 基本颜色
    GREEN = '\033[32m'     # 标准绿色
    BLUE = '\033[34m'      # 标准蓝色
    YELLOW = '\033[33m'    # 标准黄色
    RED = '\033[31m'       # 标准红色
    CYAN = '\033[36m'      # 青色
    MAGENTA = '\033[35m'   # 紫色
    
    # 高亮色（更明亮）
    BRIGHT_GREEN = '\033[92m'  # 亮绿色
    BRIGHT_BLUE = '\033[94m'   # 亮蓝色
    BRIGHT_YELLOW = '\033[93m' # 亮黄色
    BRIGHT_RED = '\033[91m'    # 亮红色
    BRIGHT_CYAN = '\033[96m'   # 亮青色
    BRIGHT_MAGENTA = '\033[95m' # 亮紫色
    
    # 格式
    BOLD = '\033[1;1m'     # 粗体，使用1;1m增加兼容性
    UNDERLINE = '\033[4m'  # 下划线
    ITALIC = '\033[3m'     # 斜体（部分终端支持）
    
    # 重置
    END = '\033[0m'

def print_separator(char="─"):
    """
    根据终端宽度打印一整行分隔线。
    Args:
        char: 分隔线字符，默认为“─”
    """
    import shutil
    width = shutil.get_terminal_size().columns
    print(char * width)

def extract_answer(raw_text: str) -> str:
    clean_text = raw_text.strip()
    
    # 去除所有 <think>...</think> 块
    while "<think>" in clean_text and "</think>" in clean_text:
        think_start = clean_text.find("<think>")
        think_end = clean_text.find("</think>") + len("</think>")
        clean_text = clean_text[:think_start] + clean_text[think_end:]
    
    # 最后再清理一次空白字符
    return clean_text.strip()

def process_latex(text):
    """
    简单处理LaTeX数学公式，将其转换为可在终端中显示的Unicode字符
    """
    
    # LaTeX 符号到 Unicode 的映射
    latex_symbols = {
        '\\Gamma': 'Γ', '\\Delta': 'Δ', '\\Theta': 'Θ', '\\Lambda': 'Λ', '\\Xi': 'Ξ',
        '\\Pi': 'Π', '\\Sigma': 'Σ', '\\Phi': 'Φ', '\\Psi': 'Ψ', '\\Omega': 'Ω',
        '\\alpha': 'α', '\\beta': 'β', '\\gamma': 'γ', '\\delta': 'δ', '\\epsilon': 'ε',
        '\\zeta': 'ζ', '\\eta': 'η', '\\theta': 'θ', '\\iota': 'ι', '\\kappa': 'κ',
        '\\lambda': 'λ', '\\mu': 'μ', '\\nu': 'ν', '\\xi': 'ξ', '\\omicron': 'ο',
        '\\pi': 'π', '\\rho': 'ρ', '\\sigma': 'σ', '\\tau': 'τ', '\\upsilon': 'υ',
        '\\phi': 'φ', '\\chi': 'χ', '\\psi': 'ψ', '\\omega': 'ω',
        '\\infty': '∞', '\\approx': '≈', '\\neq': '≠', '\\leq': '≤', '\\geq': '≥',
        '\\times': '×', '\\cdot': '·', '\\pm': '±', '\\rightarrow': '→', '\\leftarrow': '←',
        '\\Rightarrow': '⇒', '\\Leftarrow': '⇐', '\\subset': '⊂', '\\supset': '⊃',
        '\\in': '∈', '\\notin': '∉', '\\cup': '∪', '\\cap': '∩', '\\emptyset': '∅',
        '\\sqrt': '√', '\\sum': '∑', '\\prod': '∏', '\\int': '∫', '\\partial': '∂', '\\nabla': '∇',
        '\\sin': 'sin', '\\cos': 'cos',
        '^2': '²', '^3': '³', '^n': 'ⁿ', '_1': '₁', '_2': '₂', '_3': '₃',
        '\\langle': '⟨', '\\rangle': '⟩', '\\ket': '|', '\\bra': '⟨'
    }

    # 先全局处理 \frac
    text = re.sub(r'\\frac\{([^}]*)\}\{([^}]*)\}', r'(\1)/(\2)', text)

    # 处理行内公式 $...$
    def replace_inline_latex(match):
        formula = match.group(1)
        # 按长度降序替换，避免前缀冲突
        for latex in sorted(latex_symbols.keys(), key=len, reverse=True):
            formula = formula.replace(latex, latex_symbols[latex])
        return formula

    # 处理块级公式 $$...$$
    def replace_block_latex(match):
        formula = match.group(1).strip()
        # 按长度降序替换，避免前缀冲突
        for latex in sorted(latex_symbols.keys(), key=len, reverse=True):
            formula = formula.replace(latex, latex_symbols[latex])
        return "\n" + formula + "\n"

    # 处理 |ψ⟩ 这样的量子态符号
    text = re.sub(r'\|([^>]+)\\rangle', r'|\1⟩', text)
    text = re.sub(r'\\langle([^|]+)\|', r'⟨\1|', text)

    # 应用替换规则
    text = re.sub(r'\$\$(.*?)\$\$', replace_block_latex, text, flags=re.DOTALL)
    text = re.sub(r'\$(.*?)\$', replace_inline_latex, text)

    # 全局替换未在 $ 内的 LaTeX 命令
    for latex, unicode in sorted(latex_symbols.items(), key=lambda item: len(item[0]), reverse=True):
        text = text.replace(latex, unicode)

    return text

def response(model_manager, user_input, return_raw):
    """
    流式获取模型回复并使用 Rich 渲染 Markdown 输出到终端。
    自动按段落（以空行分隔）分块渲染，支持表格、列表、代码块及保留 <think> 标签。
    支持简单的 LaTeX 数学公式渲染。
    """
    console = Console()
    raw_response = ""
    buf = ""
    for chunk in model_manager.stream_response(user_input):
        raw_response += chunk
        buf += chunk
        # 渲染完整段落
        while "\n\n" in buf:
            part, buf = buf.split("\n\n", 1)
            escaped = part.replace("<think>", "`<think>`\n").replace("</think>", "\n`</think>`")
            # 处理 LaTeX 公式
            escaped = process_latex(escaped)
            console.print(Markdown(escaped, justify="left"))
    # 渲染剩余内容
    if buf.strip():
        escaped = buf.replace("<think>", "`<think>`").replace("</think>", "`</think>`")
        # 处理 LaTeX 公式
        escaped = process_latex(escaped)
        console.print(Markdown(escaped, justify="left"))

    if return_raw:
        return raw_response
    else:
        return 0


"""
中文提示和界面文本
"""

# 通用提示
GENERAL = {
    # 命令行参数相关
    "app_description": "viby - 一个与大语言模型交互的多功能命令行工具",
    "app_epilog": "示例:\n  viby \"什么是斐波那契数列?\"\n  git diff | viby \"帮我写一个commit消息\"\n  viby --shell \"找当前目录下所有json文件\"\n",
    "prompt_help": "要发送给模型的提示内容",
    "shell_help": "生成并可选执行 shell 命令",
    "config_help": "启动交互式配置向导",
    
    # The following line is empty in the input text
    # 界面文本
    "generating": "[AI 正在生成回复...]",
    "operation_cancelled": "操作已取消。",
    "copy_success": "内容已复制到剪贴板！",
    "copy_fail": "复制失败: {0}",
    
    # 错误信息
    "config_load_error": "警告：无法从 {0} 加载配置：{1}",
    "config_save_error": "警告：无法保存配置到 {0}：{1}",
    # LLM相关
    "llm_empty_response": "【提示】模型没有返回任何内容，请尝试重新提问或检查您的提示。",
}

# 配置向导相关
CONFIG_WIZARD = {
    # 模型名称本地化
    "model_qwen3": "qwen3:30b",
    "model_deepseek": "deepseek-v3",
    "model_gpt4o": "gpt-4o",
    "model_custom": "自定义",
    # 标题和提示
    "header_title": "Viby 配置向导",
    "checking_chinese": "正在检查终端是否支持中文...",
    
    # 输入验证
    "invalid_number": "请输入有效数字!",
    "number_range_error": "请输入 1-{0} 之间的数字!",
    "url_error": "URL 必须以 http:// 或 https:// 开头!",
    "input_error": "输入错误！请从以下选项中选择: {0}",
    "temperature_range": "温度值必须在 0.0 到 1.0 之间!",
    "invalid_decimal": "请输入有效的小数!",
    "tokens_positive": "令牌数必须大于 0!",
    "invalid_integer": "请输入有效的整数!",
    "timeout_positive": "超时时间必须大于 0!",
    
    # 提示文本
    "language_prompt": "请选择界面语言:",
    "selected_language": "已选择中文界面",
    "model_prompt": "选择默认模型",
    "temperature_prompt": "温度参数 (0.0-1.0)",
    "max_tokens_prompt": "最大令牌数",
    "api_url_prompt": "API 基础URL",
    "api_timeout_prompt": "API 超时时间(秒)",
    "api_key_prompt": "API 密钥(如需)",
    "custom_model_prompt": "选择默认模型 (自定义)",
    "config_saved": "配置已保存至",
    "continue_prompt": "按 Enter 键继续...",
}

# Shell 命令相关
SHELL = {
    "command_prompt": "请只生成一个用于：{0} 的 shell 命令。只返回命令本身，不要解释，不要 markdown。",
    "generating_command": "[AI 正在生成命令...]",
    "execute_prompt": "执行命令│  {0}  │?",
    "choice_prompt": "[r]运行, [e]编辑, [y]复制, [q]放弃 (默认: 放弃): ",
    "edit_prompt": "编辑命令（原命令: {0}）:\n> ",
    "executing": "执行命令: {0}",
    "command_complete": "命令完成 [返回码: {0}]",
    "command_error": "命令执行出错: {0}",
}



"""
Shell command execution for viby
"""

import os
import subprocess
import pyperclip

from prompt_toolkit import prompt

from viby.llm.models import ModelManager
from viby.utils.formatting import Colors
from viby.utils.formatting import extract_answer
from viby.utils.formatting import response
from viby.locale import get_text
from viby.utils.formatting import print_separator


class ShellExecutor:
    """Handles shell command generation and execution"""
    
    def __init__(self, model_manager: ModelManager):
        self.model_manager = model_manager
    
    def generate_and_execute(self, user_prompt: str) -> int:
        """生成 shell 命令并支持流式输出，用户可选择执行"""
        # 强化提示，要求只返回 shell 命令
        shell_prompt = get_text("SHELL", "command_prompt", user_prompt)

        # 流式获取命令内容
        print(f"{Colors.BLUE}{get_text('SHELL', 'generating_command')}{Colors.END}")
        raw_response = response(self.model_manager, shell_prompt, return_raw=True)
        command = extract_answer(raw_response)

        # 清理 markdown 包裹
        if command.startswith('```') and command.endswith('```'):
            command = command[3:-3].strip()
        if command.startswith('`') and command.endswith('`'):
            command = command[1:-1].strip()
        
        print(f"{Colors.BLUE}{get_text('SHELL', 'execute_prompt', command)}{Colors.END}")

        choice = input(f"{Colors.YELLOW}{get_text('SHELL', 'choice_prompt')}").strip().lower()

        if choice in ('r', 'run'):
            return self._execute_command(command)
        elif choice == 'e':
            new_command = prompt(get_text('SHELL', 'edit_prompt', command), default=command)
            if new_command:
                command = new_command
            return self._execute_command(command)
        elif choice == 'y':
            try:
                pyperclip.copy(command)
                print(f"{Colors.GREEN}{get_text('GENERAL', 'copy_success')}{Colors.END}")
            except Exception as e:
                print(f"{Colors.RED}{get_text('GENERAL', 'copy_fail', str(e))}{Colors.END}")
            return 0
        else:
            print(f"{Colors.YELLOW}{get_text('GENERAL', 'operation_cancelled')}{Colors.END}")
            return 0
    
    def _execute_command(self, command: str) -> int:
        """执行 shell 命令并返回其退出代码"""
        try:
            # 使用用户的 shell 执行
            shell = os.environ.get('SHELL', '/bin/sh')
            
            print(f"{Colors.BOLD}{Colors.BLUE}{get_text('SHELL', 'executing', command)}{Colors.END}")
            print(f"{Colors.BLUE}", end="")
            print_separator()
            print(Colors.END, end="")
            
            process = subprocess.run(
                command,
                shell=True,
                executable=shell
            )
            
            # 根据返回码显示不同颜色
            status_color = Colors.GREEN if process.returncode == 0 else Colors.RED
            print(f"{Colors.BLUE}", end="")
            print_separator()
            print(Colors.END, end="")
            print(f"{status_color}{get_text('SHELL', 'command_complete', process.returncode)}{Colors.END}")
            
            return process.returncode
        except Exception as e:
            print(f"{Colors.RED}{get_text('SHELL', 'command_error', str(e))}{Colors.END}")
            return 1



"""
Command line argument parsing for viby
"""

import argparse
import sys
from typing import Tuple

from viby.locale import get_text


def get_parser() -> argparse.ArgumentParser:
    parser = argparse.ArgumentParser(
        description=get_text("GENERAL", "app_description"),
        epilog=get_text("GENERAL", "app_epilog"),
        formatter_class=argparse.RawDescriptionHelpFormatter
    )
    parser.add_argument(
        "prompt", nargs="?", 
        help=get_text("GENERAL", "prompt_help")
    )
    parser.add_argument(
        "--shell", "-s", action="store_true",
        help=get_text("GENERAL", "shell_help")
    )
    parser.add_argument(
        "--config", "-c", action="store_true",
        help=get_text("GENERAL", "config_help")
    )
    return parser

def parse_arguments() -> argparse.Namespace:
    return get_parser().parse_args()


def process_input(args: argparse.Namespace) -> Tuple[str, bool]:
    """
    处理命令行参数和标准输入，组合成完整的用户输入
    
    Args:
        args: 解析后的命令行参数
        
    Returns:
        Tuple[str, bool]: (用户输入, 是否有效输入)
    """
    # 获取命令行提示词和管道上下文
    prompt = args.prompt.strip() if args.prompt else None
    pipe_content = sys.stdin.read().strip() if not sys.stdin.isatty() else None

    # 构造最终输入
    user_input = (
        f"{prompt}\n{pipe_content}" if prompt and pipe_content
        else prompt or pipe_content
    )

    return user_input, bool(user_input)



"""
English prompts and interface text
"""

# General prompts
GENERAL = {
    # Command line arguments related
    "app_description": "viby - A versatile command-line tool for interacting with large language models",
    "app_epilog": "Examples:\n  viby \"What is the Fibonacci sequence?\"\n  git diff | viby \"Help me write a commit message\"\n  viby --shell \"Find all json files in current directory\"\n",
    "prompt_help": "Prompt content to send to the model",
    "shell_help": "Generate and optionally execute shell commands",
    "config_help": "Launch interactive configuration wizard",
    
    # Interface text
    "generating": "[AI is generating response...]",
    "operation_cancelled": "Operation cancelled.",
    "copy_success": "Content copied to clipboard!",
    "copy_fail": "Copy failed: {0}",
    
    # Error messages
    "config_load_error": "Warning: Could not load config from {0}: {1}",
    "config_save_error": "Warning: Could not save config to {0}: {1}",

    # LLM Response
    "llm_empty_response": "Model did not return any content, please check your config",
}

# Configuration wizard related
CONFIG_WIZARD = {
    "model_qwen3": "qwen3:30b",
    "model_deepseek": "deepseek-v3",
    "model_gpt4o": "gpt-4o",
    "model_custom": "custom",
    # Headers and titles
    "header_title": "Viby Configuration Wizard",
    "checking_chinese": "Checking if terminal supports Chinese...",
    
    # Input validation
    "invalid_number": "Please enter a valid number!",
    "number_range_error": "Please enter a number between 1-{0}!",
    "url_error": "URL must start with http:// or https://!",
    "input_error": "Input error! Please choose from: {0}",
    "temperature_range": "Temperature must be between 0.0 and 1.0!",
    "invalid_decimal": "Please enter a valid decimal number!",
    "tokens_positive": "Token count must be greater than 0!",
    "invalid_integer": "Please enter a valid integer!",
    "timeout_positive": "Timeout must be greater than 0!",
    
    # Prompts
    "language_prompt": "Please select interface language:",
    "selected_language": "Selected English interface",
    "model_prompt": "Select default model",
    "temperature_prompt": "Temperature (0.0-1.0)",
    "max_tokens_prompt": "Maximum tokens",
    "api_url_prompt": "API base URL",
    "api_timeout_prompt": "API timeout (seconds)",
    "api_key_prompt": "API key (if needed)",
    "custom_model_prompt": "Select default model (custom)",
    "config_saved": "Configuration saved to",
    "continue_prompt": "Press Enter to continue...",
}

# Shell command related
SHELL = {
    "command_prompt": "Please generate only a shell command for: {0}. Return only the command itself, no explanation, no markdown.",
    "generating_command": "[AI is generating command...]",
    "execute_prompt": "Execute command│  {0}  │?",
    "choice_prompt": "[r]run, [e]edit, [y]copy, [q]quit (default: quit): ",
    "edit_prompt": "Edit command (original: {0}):\n> ",
    "executing": "Executing command: {0}",
    "command_complete": "Command completed [Return code: {0}]",
    "command_error": "Command execution error: {0}",
}



"""
Interactive configuration wizard module
"""

import os
import sys
import shutil
from viby.locale import get_text, init_text_manager
from viby.utils.formatting import print_separator


def print_header(title):
    """打印配置向导标题"""
    print()
    print_separator("=")
    print(f"{title:^{shutil.get_terminal_size().columns}}")
    print_separator("=")
    print()


def get_input(prompt, default=None, validator=None, choices=None):
    """获取用户输入，支持默认值和验证"""
    if default is not None:
        prompt = f"{prompt} [{default}]: "
    else:
        prompt = f"{prompt}: "
    
    while True:
        user_input = input(prompt).strip()
        
        # 用户未输入，使用默认值
        if not user_input and default is not None:
            return default
        
        # 如果有选项限制，验证输入
        if choices and user_input not in choices:
            print(f"输入错误！请从以下选项中选择: {', '.join(choices)}")
            continue
        
        # 如果有验证函数，验证输入
        if validator and not validator(user_input):
            continue
            
        return user_input


def number_choice(choices, prompt):
    """显示编号选项并获取用户选择"""
    print(prompt)
    for i, choice in enumerate(choices, 1):
        print(f"  {i}. {choice}")
    
    while True:
        try:
            choice = input("[1]: ").strip()
            if not choice:
                return choices[0]  # 默认第一个选项
            
            choice_num = int(choice)
            if 1 <= choice_num <= len(choices):
                return choices[choice_num - 1]
            else:
                print(get_text("CONFIG_WIZARD", "number_range_error").format(len(choices)))
        except ValueError:
            print(get_text("CONFIG_WIZARD", "invalid_number"))


def validate_url(url):
    """验证URL格式"""
    if not url.startswith(("http://", "https://")):
        print(get_text("CONFIG_WIZARD", "url_error"))
        return False
    return True


def run_config_wizard(config):
    """运行交互式配置向导"""
    # Check Chinese support in current terminal
    is_chinese_supported = True
    try:
        print(get_text("CONFIG_WIZARD", "checking_chinese"))
        sys.stdout.write("测试中文支持\n")
        sys.stdout.flush()
    except UnicodeEncodeError:
        is_chinese_supported = False
    
    # 清屏
    os.system('cls' if os.name == 'nt' else 'clear')
    
    # 初始化语言界面文字
    if is_chinese_supported:
        language_choices = ["English", "中文"]
        title = "Viby 配置向导 / Viby Configuration Wizard"
        language_prompt = "请选择界面语言 / Please select interface language:"
    else:
        language_choices = ["English", "Chinese"]
        title = "Viby Configuration Wizard"
        language_prompt = "Please select interface language:"
    
    print_header(title)
    
    # 语言选择
    language = number_choice(language_choices, language_prompt)
    if language in ["中文", "Chinese"]:
        config.language = "zh-CN"
        init_text_manager(config)
        print("\n" + get_text("CONFIG_WIZARD", "selected_language"))
        
    else:
        config.language = "en-US"
        init_text_manager(config)
        print("\n" + get_text("CONFIG_WIZARD", "selected_language"))
        
    model_prompt = get_text("CONFIG_WIZARD", "model_prompt")
    temp_prompt = get_text("CONFIG_WIZARD", "temperature_prompt")
    max_tokens_prompt = get_text("CONFIG_WIZARD", "max_tokens_prompt")
    api_url_prompt = get_text("CONFIG_WIZARD", "api_url_prompt")
    api_timeout_prompt = get_text("CONFIG_WIZARD", "api_timeout_prompt")
    api_key_prompt = get_text("CONFIG_WIZARD", "api_key_prompt")
    save_prompt = get_text("CONFIG_WIZARD", "config_saved")
    continue_prompt = get_text("CONFIG_WIZARD", "continue_prompt")
    
    print()
    print_separator()

    # API URL
    config.base_url = get_input(api_url_prompt, config.base_url, validator=validate_url)
    
    # API Key
    config.api_key = get_input(api_key_prompt, config.api_key or "")

    # 模型选择
    models = [
    get_text("CONFIG_WIZARD", "model_qwen3"),
    get_text("CONFIG_WIZARD", "model_deepseek"),
    get_text("CONFIG_WIZARD", "model_gpt4o"),
    get_text("CONFIG_WIZARD", "model_custom")
]
    chosen_model = number_choice(models, model_prompt)
    if chosen_model == get_text("CONFIG_WIZARD", "model_custom"):
        config.model = get_input(f"{model_prompt} ({get_text('CONFIG_WIZARD', 'model_custom')})", config.model)
    else:
        config.model = chosen_model
    
    # 温度设置
    while True:
        temp = get_input(temp_prompt, str(config.temperature))
        try:
            temp_value = float(temp)
            if 0.0 <= temp_value <= 1.0:
                config.temperature = temp_value
                break
            print(get_text("CONFIG_WIZARD", "temperature_range"))
        except ValueError:
            print(get_text("CONFIG_WIZARD", "invalid_decimal"))
    
    # 最大令牌数
    while True:
        max_tokens = get_input(max_tokens_prompt, str(config.max_tokens))
        try:
            tokens_value = int(max_tokens)
            if tokens_value > 0:
                config.max_tokens = tokens_value
                break
            print(get_text("CONFIG_WIZARD", "tokens_positive"))
        except ValueError:
            print(get_text("CONFIG_WIZARD", "invalid_integer"))
    
    
    # API 超时
    while True:
        timeout = get_input(api_timeout_prompt, str(config.api_timeout))
        try:
            timeout_value = int(timeout)
            if timeout_value > 0:
                config.api_timeout = timeout_value
                break
            print(get_text("CONFIG_WIZARD", "timeout_positive"))
        except ValueError:
            print(get_text("CONFIG_WIZARD", "invalid_integer"))
    
    
    # 保存配置
    config.save_config()
    
    print()
    print_separator()
    print(f"{save_prompt}: {config.config_path}")
    input(f"\n{continue_prompt}")
    return config



"""
viby 配置管理模块
"""

import os
import yaml
from typing import Dict, Any, Optional


class Config:
    """viby 应用的配置管理器"""
    
    def __init__(self):
        # Default configuration parameters
        self.model = "qwen3:30b"
        self.temperature = 0.7
        self.max_tokens = 40960
        self.base_url = "http://localhost:11434"
        self.api_timeout = 300
        self.api_key = ""
        self.language = "en-US"  # options: en-US, zh-CN

        self.config_dir = os.path.join(os.path.expanduser("~"), ".config", "viby")
        self.config_path = os.path.join(self.config_dir, "config.yaml")

        # 确保配置目录存在
        os.makedirs(self.config_dir, exist_ok=True)

        # 如果配置文件不存在，标记为首次启动
        self.is_first_run = not os.path.exists(self.config_path)
        if self.is_first_run:
            # 先保存默认配置，稍后会被通过向导替换
            self.save_config()
        
        # 如果存在则加载配置
        self.load_config()
    
    def load_config(self) -> None:
        """Load configuration from YAML file"""
        path = self.config_path
        try:
            if os.path.exists(path):
                with open(path, 'r', encoding='utf-8') as f:
                    config_data = yaml.safe_load(f)
                if not config_data:
                    return
                # Update instance attributes from config file
                for key, value in config_data.items():
                    if hasattr(self, key):
                        setattr(self, key, value)
        except Exception as e:
            print(f"Warning: Could not load config from {path}: {e}")
    
    def save_config(self) -> None:
        """将当前配置保存到 YAML 文件"""
        os.makedirs(os.path.dirname(self.config_path), exist_ok=True)
        config_data = {
            key: value for key, value in self.__dict__.items()
            if not key.startswith('_') and key != 'config_path' and key != 'config_dir' and key != 'is_first_run'
        }
        try:
            with open(self.config_path, 'w', encoding='utf-8') as f:
                yaml.safe_dump(config_data, f, sort_keys=False)
        except Exception as e:
            print(f"Warning: Could not save config to {self.config_path}: {e}")
    
    def get_model_config(self, model_name: Optional[str] = None) -> Dict[str, Any]:
        """获取指定模型的配置"""
        model = model_name or self.model
        model_config = {
            "model": model,
            "temperature": self.temperature,
            "max_tokens": self.max_tokens,
            "base_url": self.base_url,
            "api_key": self.api_key,
        }
        return model_config
